@@ -11,13 +11,13 @@ from .player import AbstractPlayer
 
 def _cleanup(prop):
     try:
-        prop = prop.replace('%', '')
-        prop = prop.replace(',', '')
-        return prop.replace('+', '')
+        prop = prop.replace("%", "")
+        prop = prop.replace(",", "")
+        return prop.replace("+", "")
     # Occurs when a value is of Nonetype. When that happens, return a blank
     # string as whatever have come in had an incomplete value.
     except AttributeError:
-        return ''
+        return ""
 
 
 def _int_property_decorator(func):
@@ -32,6 +32,7 @@ def _int_property_decorator(func):
         except ValueError:
             # If there is no value, default to None
             return None
+
     return wrapper
 
 
@@ -47,6 +48,7 @@ def _float_property_decorator(func):
         except ValueError:
             # If there is no value, default to None
             return None
+
     return wrapper
 
 
@@ -59,6 +61,7 @@ def _most_recent_decorator(func):
         index = seasons.index(season)
         prop = func(*args)
         return prop[index]
+
     return wrapper
 
 
@@ -91,8 +94,9 @@ class Player(AbstractPlayer):
         number starting at '1' for the first time that player ID has been used
         and increments by 1 for every successive player.
     """
+
     def __init__(self, player_id):
-        self._most_recent_season = ''
+        self._most_recent_season = ""
         self._index = None
         self._player_id = player_id
         self._season = None
@@ -122,7 +126,7 @@ class Player(AbstractPlayer):
         """
         Return the string representation of the class.
         """
-        return f'{self.name} ({self.player_id})'
+        return f"{self.name} ({self.player_id})"
 
     def __repr__(self):
         """
@@ -169,7 +173,7 @@ class Player(AbstractPlayer):
             A string representation of the season in the format 'YYYY-YY', such
             as '2017-18'.
         """
-        return utils._parse_field(PLAYER_SCHEME, row, 'season')
+        return utils._parse_field(PLAYER_SCHEME, row, "season")
 
     def _combine_season_stats(self, table_rows, career_stats, all_stats_dict):
         """
@@ -204,17 +208,17 @@ class Player(AbstractPlayer):
         for row in table_rows:
             season = self._parse_season(row)
             try:
-                all_stats_dict[season]['data'] += str(row)
+                all_stats_dict[season]["data"] += str(row)
             except KeyError:
-                all_stats_dict[season] = {'data': str(row)}
+                all_stats_dict[season] = {"data": str(row)}
             most_recent_season = season
         self._most_recent_season = most_recent_season
         if not career_stats:
             return all_stats_dict
         try:
-            all_stats_dict['Career']['data'] += str(next(career_stats))
+            all_stats_dict["Career"]["data"] += str(next(career_stats))
         except KeyError:
-            all_stats_dict['Career'] = {'data': str(next(career_stats))}
+            all_stats_dict["Career"] = {"data": str(next(career_stats))}
         return all_stats_dict
 
     def _combine_all_stats(self, player_info):
@@ -239,15 +243,14 @@ class Player(AbstractPlayer):
         """
         all_stats_dict = {}
 
-        for table_id in ['players_totals', 'players_advanced']:
-            table_items = utils._get_stats_table(player_info,
-                                                 'table#%s' % table_id)
-            career_items = utils._get_stats_table(player_info,
-                                                  'table#%s' % table_id,
-                                                  footer=True)
-            all_stats_dict = self._combine_season_stats(table_items,
-                                                        career_items,
-                                                        all_stats_dict)
+        for table_id in ["players_totals", "players_advanced"]:
+            table_items = utils._get_stats_table(player_info, "table#%s" % table_id)
+            career_items = utils._get_stats_table(
+                player_info, "table#%s" % table_id, footer=True
+            )
+            all_stats_dict = self._combine_season_stats(
+                table_items, career_items, all_stats_dict
+            )
         return all_stats_dict
 
     def _parse_player_information(self, player_info):
@@ -263,7 +266,7 @@ class Player(AbstractPlayer):
         player_info : PyQuery object
             A PyQuery object containing the HTML from the player's stats page.
         """
-        for field in ['_height', '_weight', '_name']:
+        for field in ["_height", "_weight", "_name"]:
             short_field = str(field)[1:]
             value = utils._parse_field(PLAYER_SCHEME, player_info, short_field)
             setattr(self, field, value)
@@ -282,10 +285,10 @@ class Player(AbstractPlayer):
             A PyQuery object of the player's information on the HTML stats
             page.
         """
-        for section in player_info('div#meta p').items():
-            if 'Position' in str(section):
-                position = section.text().replace('Position: ', '')
-                setattr(self, '_position', position)
+        for section in player_info("div#meta p").items():
+            if "Position" in str(section):
+                position = section.text().replace("Position: ", "")
+                setattr(self, "_position", position)
                 break
 
     def _parse_conference(self, stats):
@@ -305,11 +308,9 @@ class Player(AbstractPlayer):
         string
             Returns a string of the conference abbreviation, such as 'big-12'.
         """
-        conference_tag = stats(PLAYER_SCHEME['conference'])
-        conference = re.sub(r'.*/cbb/conferences/',
-                            '',
-                            str(conference_tag('a')))
-        conference = re.sub(r'/.*', '', conference)
+        conference_tag = stats(PLAYER_SCHEME["conference"])
+        conference = re.sub(r".*/cbb/conferences/", "", str(conference_tag("a")))
+        conference = re.sub(r"/.*", "", conference)
         return conference
 
     def _parse_team_abbreviation(self, stats):
@@ -330,9 +331,9 @@ class Player(AbstractPlayer):
             Returns a string of the team's abbreviation, such as 'PURDUE' for
             the Purdue Boilermakers.
         """
-        team_tag = stats(PLAYER_SCHEME['team_abbreviation'])
-        team = re.sub(r'.*/cbb/schools/', '', str(team_tag('a')))
-        team = re.sub(r'/.*', '', team)
+        team_tag = stats(PLAYER_SCHEME["team_abbreviation"])
+        team = re.sub(r".*/cbb/schools/", "", str(team_tag("a")))
+        team = re.sub(r"/.*", "", team)
         return team
 
     def _pull_player_data(self):
@@ -355,7 +356,7 @@ class Player(AbstractPlayer):
         self._parse_player_information(player_info)
         self._parse_player_position(player_info)
         all_stats = self._combine_all_stats(player_info)
-        setattr(self, '_season', all_stats.keys())
+        setattr(self, "_season", all_stats.keys())
         return all_stats
 
     def _find_initial_index(self):
@@ -368,12 +369,12 @@ class Player(AbstractPlayer):
         """
         index = 0
         for season in self._season:
-            if season == 'Career':
+            if season == "Career":
                 self._index = index
                 break
             index += 1
 
-    def __call__(self, requested_season=''):
+    def __call__(self, requested_season=""):
         """
         Specify a different season to pull stats from.
 
@@ -392,9 +393,8 @@ class Player(AbstractPlayer):
         Player class instance
             Returns the class instance with the updated stats being referenced.
         """
-        if requested_season.lower() == 'career' or \
-           requested_season == '':
-            requested_season = 'Career'
+        if requested_season.lower() == "career" or requested_season == "":
+            requested_season = "Career"
         index = 0
         for season in self._season:
             if season == requested_season:
@@ -419,58 +419,57 @@ class Player(AbstractPlayer):
             attribute for the specified index.
         """
         fields_to_include = {
-            'assist_percentage': self.assist_percentage,
-            'assists': self.assists,
-            'block_percentage': self.block_percentage,
-            'blocks': self.blocks,
-            'box_plus_minus': self.box_plus_minus,
-            'conference': self.conference,
-            'defensive_box_plus_minus': self.defensive_box_plus_minus,
-            'defensive_rebound_percentage': self.defensive_rebound_percentage,
-            'defensive_rebounds': self.defensive_rebounds,
-            'defensive_win_shares': self.defensive_win_shares,
-            'effective_field_goal_percentage':
-            self.effective_field_goal_percentage,
-            'field_goal_attempts': self.field_goal_attempts,
-            'field_goal_percentage': self.field_goal_percentage,
-            'field_goals': self.field_goals,
-            'free_throw_attempt_rate': self.free_throw_attempt_rate,
-            'free_throw_attempts': self.free_throw_attempts,
-            'free_throw_percentage': self.free_throw_percentage,
-            'free_throws': self.free_throws,
-            'games_played': self.games_played,
-            'games_started': self.games_started,
-            'height': self.height,
-            'minutes_played': self.minutes_played,
-            'offensive_box_plus_minus': self.offensive_box_plus_minus,
-            'offensive_rebound_percentage': self.offensive_rebound_percentage,
-            'offensive_rebounds': self.offensive_rebounds,
-            'offensive_win_shares': self.offensive_win_shares,
-            'personal_fouls': self.personal_fouls,
-            'player_efficiency_rating': self.player_efficiency_rating,
-            'player_id': self.player_id,
-            'points': self.points,
-            'points_produced': self.points_produced,
-            'position': self.position,
-            'steal_percentage': self.steal_percentage,
-            'steals': self.steals,
-            'team_abbreviation': self.team_abbreviation,
-            'three_point_attempt_rate': self.three_point_attempt_rate,
-            'three_point_attempts': self.three_point_attempts,
-            'three_point_percentage': self.three_point_percentage,
-            'three_pointers': self.three_pointers,
-            'total_rebound_percentage': self.total_rebound_percentage,
-            'total_rebounds': self.total_rebounds,
-            'true_shooting_percentage': self.true_shooting_percentage,
-            'turnover_percentage': self.turnover_percentage,
-            'turnovers': self.turnovers,
-            'two_point_attempts': self.two_point_attempts,
-            'two_point_percentage': self.two_point_percentage,
-            'two_pointers': self.two_pointers,
-            'usage_percentage': self.usage_percentage,
-            'weight': self.weight,
-            'win_shares': self.win_shares,
-            'win_shares_per_40_minutes': self.win_shares_per_40_minutes,
+            "assist_percentage": self.assist_percentage,
+            "assists": self.assists,
+            "block_percentage": self.block_percentage,
+            "blocks": self.blocks,
+            "box_plus_minus": self.box_plus_minus,
+            "conference": self.conference,
+            "defensive_box_plus_minus": self.defensive_box_plus_minus,
+            "defensive_rebound_percentage": self.defensive_rebound_percentage,
+            "defensive_rebounds": self.defensive_rebounds,
+            "defensive_win_shares": self.defensive_win_shares,
+            "effective_field_goal_percentage": self.effective_field_goal_percentage,
+            "field_goal_attempts": self.field_goal_attempts,
+            "field_goal_percentage": self.field_goal_percentage,
+            "field_goals": self.field_goals,
+            "free_throw_attempt_rate": self.free_throw_attempt_rate,
+            "free_throw_attempts": self.free_throw_attempts,
+            "free_throw_percentage": self.free_throw_percentage,
+            "free_throws": self.free_throws,
+            "games_played": self.games_played,
+            "games_started": self.games_started,
+            "height": self.height,
+            "minutes_played": self.minutes_played,
+            "offensive_box_plus_minus": self.offensive_box_plus_minus,
+            "offensive_rebound_percentage": self.offensive_rebound_percentage,
+            "offensive_rebounds": self.offensive_rebounds,
+            "offensive_win_shares": self.offensive_win_shares,
+            "personal_fouls": self.personal_fouls,
+            "player_efficiency_rating": self.player_efficiency_rating,
+            "player_id": self.player_id,
+            "points": self.points,
+            "points_produced": self.points_produced,
+            "position": self.position,
+            "steal_percentage": self.steal_percentage,
+            "steals": self.steals,
+            "team_abbreviation": self.team_abbreviation,
+            "three_point_attempt_rate": self.three_point_attempt_rate,
+            "three_point_attempts": self.three_point_attempts,
+            "three_point_percentage": self.three_point_percentage,
+            "three_pointers": self.three_pointers,
+            "total_rebound_percentage": self.total_rebound_percentage,
+            "total_rebounds": self.total_rebounds,
+            "true_shooting_percentage": self.true_shooting_percentage,
+            "turnover_percentage": self.turnover_percentage,
+            "turnovers": self.turnovers,
+            "two_point_attempts": self.two_point_attempts,
+            "two_point_percentage": self.two_point_percentage,
+            "two_pointers": self.two_pointers,
+            "usage_percentage": self.usage_percentage,
+            "weight": self.weight,
+            "win_shares": self.win_shares,
+            "win_shares_per_40_minutes": self.win_shares_per_40_minutes,
         }
         return fields_to_include
 
@@ -538,7 +537,7 @@ class Player(AbstractPlayer):
         """
         if not self._weight:
             return None
-        return int(self._weight.replace('lb', ''))
+        return int(self._weight.replace("lb", ""))
 
     @_int_property_decorator
     def games_played(self):
@@ -653,6 +652,7 @@ class Roster:
         respective stats which greatly reduces the time to return a response if
         just the names and IDs are desired. Defaults to False.
     """
+
     def __init__(self, team, year=None, slim=False):
         self._team = team
         self._slim = slim
@@ -671,9 +671,11 @@ class Roster:
         if self._slim:
             players = [name for id, name in self._players.items()]
         else:
-            players = [f'{player.name} ({player.player_id})'.strip()
-                    for player in self._players]
-        return '\n'.join(players)
+            players = [
+                f"{player.name} ({player.player_id})".strip()
+                for player in self._players
+            ]
+        return "\n".join(players)
 
     def __repr__(self):
         """
@@ -741,8 +743,8 @@ class Roster:
             Returns a string of the player ID.
         """
         name_tag = player('th[data-stat="player"] a')
-        name = re.sub(r'.*/cbb/players/', '', str(name_tag))
-        return re.sub(r'\.html.*', '', name)
+        name = re.sub(r".*/cbb/players/", "", str(name_tag))
+        return re.sub(r"\.html.*", "", name)
 
     def _get_name(self, player):
         """
@@ -782,10 +784,10 @@ class Roster:
         string
             Returns a string of the coach's name.
         """
-        for line in page(PLAYER_SCHEME['summary']).find('p').items():
-            strong = line.find('strong')
-            if hasattr(strong, 'text') and strong.text().strip() == 'Coach:':
-                return line.find('a').text()
+        for line in page(PLAYER_SCHEME["summary"]).find("p").items():
+            strong = line.find("strong")
+            if hasattr(strong, "text") and strong.text().strip() == "Coach:":
+                return line.find("a").text()
 
     def _find_players_with_coach(self, year):
         """
@@ -804,21 +806,24 @@ class Roster:
             from.
         """
         if not year:
-            year = utils._find_year_for_season('ncaab')
+            year = utils._find_year_for_season("ncaab")
             # If stats for the requested season do not exist yet (as is the
             # case right before a new season begins), attempt to pull the
             # previous year's stats. If it exists, use the previous year
             # instead.
-            if not utils._url_exists(self._create_url(year)) and \
-               utils._url_exists(self._create_url(str(int(year) - 1))):
+            if not utils._url_exists(self._create_url(year)) and utils._url_exists(
+                self._create_url(str(int(year) - 1))
+            ):
                 year = str(int(year) - 1)
         url = self._create_url(year)
         page = self._pull_team_page(url)
         if not page:
-            output = ("Can't pull requested team page. Ensure the following "
-                      "URL exists: %s" % url)
+            output = (
+                "Can't pull requested team page. Ensure the following "
+                "URL exists: %s" % url
+            )
             raise ValueError(output)
-        players = page('table#roster tbody tr').items()
+        players = page("table#roster tbody tr").items()
         for player in players:
             player_id = self._get_id(player)
             if self._slim:
