@@ -19,6 +19,7 @@ def _int_property_decorator(func):
         except (ValueError, TypeError, IndexError):
             # If there is no value, default to None
             return None
+
     return wrapper
 
 
@@ -33,6 +34,7 @@ def _float_property_decorator(func):
         except (ValueError, TypeError, IndexError):
             # If there is no value, default to None
             return None
+
     return wrapper
 
 
@@ -169,18 +171,20 @@ class AbstractPlayer:
         """
         for field in self.__dict__:
             short_field = str(field)[1:]
-            if short_field == 'player_id' or \
-               short_field == 'index' or \
-               short_field == 'most_recent_season' or \
-               short_field == 'name' or \
-               short_field == 'height' or \
-               short_field == 'weight' or \
-               short_field == 'season':
+            if (
+                short_field == "player_id"
+                or short_field == "index"
+                or short_field == "most_recent_season"
+                or short_field == "name"
+                or short_field == "height"
+                or short_field == "weight"
+                or short_field == "season"
+            ):
                 continue
             field_stats = []
             if type(player_data) == dict:
                 for year, data in player_data.items():
-                    stats = pq(data['data'])
+                    stats = pq(data["data"])
                     value = self._parse_value(stats, short_field)
                     field_stats.append(value)
             else:
