@@ -45,9 +45,18 @@ class Team:
         instead of downloading from sports-reference.com. This file should be
         of the Defensive Stats page for the designated year.
     """
-    def __init__(self, team_name=None, team_data=None, team_conference=None,
-                 year=None, season_page=None, offensive_stats=None,
-                 defensive_stats=None, recompute_conferences=False):
+
+    def __init__(
+        self,
+        team_name=None,
+        team_data=None,
+        team_conference=None,
+        year=None,
+        season_page=None,
+        offensive_stats=None,
+        defensive_stats=None,
+        recompute_conferences=False,
+    ):
         self._team_conference = team_conference
         self._year = year
         self._abbreviation = None
@@ -107,9 +116,9 @@ class Team:
         self._opponents_yards_from_penalties = None
 
         if team_name:
-            team_data = self._retrieve_team_data(year, team_name, season_page,
-                                                 offensive_stats,
-                                                 defensive_stats)
+            team_data = self._retrieve_team_data(
+                year, team_name, season_page, offensive_stats, defensive_stats
+            )
         if team_conference:
             self._team_conference = team_conference
         elif recompute_conferences:
@@ -118,14 +127,14 @@ class Team:
         else:
             conferences_dict = CONFERENCE_DICT
             self._team_conference = conferences_dict[team_name.lower()]
-                    
+
         self._parse_team_data(team_data)
 
     def __str__(self):
         """
         Return the string representation of the class.
         """
-        return f'{self.name} ({self.abbreviation}) - {self._year}'
+        return f"{self.name} ({self.abbreviation}) - {self._year}"
 
     def __repr__(self):
         """
@@ -133,8 +142,9 @@ class Team:
         """
         return self.__str__()
 
-    def _retrieve_team_data(self, year, team_name, season_page,
-                            offensive_stats, defensive_stats):
+    def _retrieve_team_data(
+        self, year, team_name, season_page, offensive_stats, defensive_stats
+    ):
         """
         Pull all stats for a specific team.
 
@@ -168,11 +178,11 @@ class Team:
             Returns a PyQuery object containing all stats and information for
             the specified team.
         """
-        team_data_dict, year = _retrieve_all_teams(year, season_page,
-                                                   offensive_stats,
-                                                   defensive_stats)
+        team_data_dict, year = _retrieve_all_teams(
+            year, season_page, offensive_stats, defensive_stats
+        )
         self._year = year
-        team_data = team_data_dict[team_name]['data']
+        team_data = team_data_dict[team_name]["data"]
         return team_data
 
     def _parse_team_data(self, team_data):
@@ -195,12 +205,9 @@ class Team:
             multiple rows in a single string.
         """
         for field in self.__dict__:
-            if field == '_year' or \
-               field == '_team_conference':
+            if field == "_year" or field == "_team_conference":
                 continue
-            value = utils._parse_field(PARSING_SCHEME,
-                                       team_data,
-                                       str(field)[1:])
+            value = utils._parse_field(PARSING_SCHEME, team_data, str(field)[1:])
             setattr(self, field, value)
 
     @property
@@ -211,66 +218,62 @@ class Team:
         team, such as 'PURDUE'.
         """
         fields_to_include = {
-            'abbreviation': self.abbreviation,
-            'conference': self.conference,
-            'conference_losses': self.conference_losses,
-            'conference_win_percentage': self.conference_win_percentage,
-            'conference_wins': self.conference_wins,
-            'first_downs': self.first_downs,
-            'opponents_first_downs': self.opponents_first_downs,
-            'first_downs_from_penalties': self.first_downs_from_penalties,
-            'opponents_first_downs_from_penalties':
-                self.opponents_first_downs_from_penalties,
-            'fumbles_lost': self.fumbles_lost,
-            'opponents_fumbles_lost': self.opponents_fumbles_lost,
-            'games': self.games,
-            'interceptions': self.interceptions,
-            'opponents_interceptions': self.opponents_interceptions,
-            'losses': self.losses,
-            'name': self.name,
-            'pass_attempts': self.pass_attempts,
-            'opponents_pass_attempts': self.opponents_pass_attempts,
-            'pass_completion_percentage': self.pass_completion_percentage,
-            'opponents_pass_completion_percentage':
-                self.opponents_pass_completion_percentage,
-            'pass_completions': self.pass_completions,
-            'opponents_pass_completions': self.opponents_pass_completions,
-            'pass_first_downs': self.pass_first_downs,
-            'opponents_pass_first_downs': self.opponents_pass_first_downs,
-            'pass_touchdowns': self.pass_touchdowns,
-            'opponents_pass_touchdowns': self.opponents_pass_touchdowns,
-            'pass_yards': self.pass_yards,
-            'opponents_pass_yards': self.opponents_pass_yards,
-            'penalties': self.penalties,
-            'opponents_penalties': self.opponents_penalties,
-            'plays': self.plays,
-            'opponents_plays': self.opponents_plays,
-            'points_against_per_game': self.points_against_per_game,
-            'points_per_game': self.points_per_game,
-            'rush_attempts': self.rush_attempts,
-            'opponents_rush_attempts': self.opponents_rush_attempts,
-            'rush_first_downs': self.rush_first_downs,
-            'opponents_rush_first_downs': self.opponents_rush_first_downs,
-            'rush_touchdowns': self.rush_touchdowns,
-            'opponents_rush_touchdowns': self.opponents_rush_touchdowns,
-            'rush_yards': self.rush_yards,
-            'opponents_rush_yards': self.opponents_rush_yards,
-            'rush_yards_per_attempt': self.rush_yards_per_attempt,
-            'opponents_rush_yards_per_attempt':
-                self.opponents_rush_yards_per_attempt,
-            'simple_rating_system': self.simple_rating_system,
-            'strength_of_schedule': self.strength_of_schedule,
-            'turnovers': self.turnovers,
-            'opponents_turnovers': self.opponents_turnovers,
-            'win_percentage': self.win_percentage,
-            'wins': self.wins,
-            'yards': self.yards,
-            'opponents_yards': self.opponents_yards,
-            'yards_from_penalties': self.yards_from_penalties,
-            'opponents_yards_from_penalties':
-                self.opponents_yards_from_penalties,
-            'yards_per_play': self.yards_per_play,
-            'opponents_yards_per_play': self.opponents_yards_per_play
+            "abbreviation": self.abbreviation,
+            "conference": self.conference,
+            "conference_losses": self.conference_losses,
+            "conference_win_percentage": self.conference_win_percentage,
+            "conference_wins": self.conference_wins,
+            "first_downs": self.first_downs,
+            "opponents_first_downs": self.opponents_first_downs,
+            "first_downs_from_penalties": self.first_downs_from_penalties,
+            "opponents_first_downs_from_penalties": self.opponents_first_downs_from_penalties,
+            "fumbles_lost": self.fumbles_lost,
+            "opponents_fumbles_lost": self.opponents_fumbles_lost,
+            "games": self.games,
+            "interceptions": self.interceptions,
+            "opponents_interceptions": self.opponents_interceptions,
+            "losses": self.losses,
+            "name": self.name,
+            "pass_attempts": self.pass_attempts,
+            "opponents_pass_attempts": self.opponents_pass_attempts,
+            "pass_completion_percentage": self.pass_completion_percentage,
+            "opponents_pass_completion_percentage": self.opponents_pass_completion_percentage,
+            "pass_completions": self.pass_completions,
+            "opponents_pass_completions": self.opponents_pass_completions,
+            "pass_first_downs": self.pass_first_downs,
+            "opponents_pass_first_downs": self.opponents_pass_first_downs,
+            "pass_touchdowns": self.pass_touchdowns,
+            "opponents_pass_touchdowns": self.opponents_pass_touchdowns,
+            "pass_yards": self.pass_yards,
+            "opponents_pass_yards": self.opponents_pass_yards,
+            "penalties": self.penalties,
+            "opponents_penalties": self.opponents_penalties,
+            "plays": self.plays,
+            "opponents_plays": self.opponents_plays,
+            "points_against_per_game": self.points_against_per_game,
+            "points_per_game": self.points_per_game,
+            "rush_attempts": self.rush_attempts,
+            "opponents_rush_attempts": self.opponents_rush_attempts,
+            "rush_first_downs": self.rush_first_downs,
+            "opponents_rush_first_downs": self.opponents_rush_first_downs,
+            "rush_touchdowns": self.rush_touchdowns,
+            "opponents_rush_touchdowns": self.opponents_rush_touchdowns,
+            "rush_yards": self.rush_yards,
+            "opponents_rush_yards": self.opponents_rush_yards,
+            "rush_yards_per_attempt": self.rush_yards_per_attempt,
+            "opponents_rush_yards_per_attempt": self.opponents_rush_yards_per_attempt,
+            "simple_rating_system": self.simple_rating_system,
+            "strength_of_schedule": self.strength_of_schedule,
+            "turnovers": self.turnovers,
+            "opponents_turnovers": self.opponents_turnovers,
+            "win_percentage": self.win_percentage,
+            "wins": self.wins,
+            "yards": self.yards,
+            "opponents_yards": self.opponents_yards,
+            "yards_from_penalties": self.yards_from_penalties,
+            "opponents_yards_from_penalties": self.opponents_yards_from_penalties,
+            "yards_per_play": self.yards_per_play,
+            "opponents_yards_per_play": self.opponents_yards_per_play,
         }
         return pd.DataFrame([fields_to_include], index=[self._abbreviation])
 
@@ -762,8 +765,15 @@ class Teams:
         instead of downloading from sports-reference.com. This file should be
         of the Defensive Stats page for the designated year.
     """
-    def __init__(self, year=None, season_page=None, offensive_stats=None,
-                 defensive_stats=None, recompute_conferences=False):
+
+    def __init__(
+        self,
+        year=None,
+        season_page=None,
+        offensive_stats=None,
+        defensive_stats=None,
+        recompute_conferences=False,
+    ):
         self._teams = []
         if recompute_conferences:
             self._conferences_dict = Conferences(year).team_conference
@@ -771,9 +781,9 @@ class Teams:
             self._conferences_dict = CONFERENCE_DICT
         # self._conferences_dict = Conferences(year, True).team_conference
 
-        team_data_dict, year = _retrieve_all_teams(year, season_page,
-                                                   offensive_stats,
-                                                   defensive_stats)
+        team_data_dict, year = _retrieve_all_teams(
+            year, season_page, offensive_stats, defensive_stats
+        )
         self._instantiate_teams(team_data_dict, year)
 
     def __getitem__(self, abbreviation):
@@ -802,7 +812,7 @@ class Teams:
         for team in self._teams:
             if team.abbreviation.upper() == abbreviation.upper():
                 return team
-        raise ValueError('Team abbreviation %s not found' % abbreviation)
+        raise ValueError("Team abbreviation %s not found" % abbreviation)
 
     def __call__(self, abbreviation):
         """
@@ -828,9 +838,8 @@ class Teams:
         """
         Return the string representation of the class.
         """
-        teams = [f'{team.name} ({team.abbreviation})'.strip()
-                 for team in self._teams]
-        return '\n'.join(teams)
+        teams = [f"{team.name} ({team.abbreviation})".strip() for team in self._teams]
+        return "\n".join(teams)
 
     def __repr__(self):
         """
@@ -872,9 +881,9 @@ class Teams:
                 continue
             else:
                 conference = self._conferences_dict[team_name.lower()]
-            team = Team(team_data=team_data['data'],
-                        team_conference=conference,
-                        year=year)
+            team = Team(
+                team_data=team_data["data"], team_conference=conference, year=year
+            )
             self._teams.append(team)
 
     @property
