@@ -6,14 +6,14 @@ from urllib.error import HTTPError
 from .. import utils
 from ..constants import AWAY, HOME
 from ..decorators import int_property_decorator
-from .constants import (BOXSCORE_ELEMENT_INDEX,
-                        BOXSCORE_ELEMENT_SUB_INDEX,
-                        BOXSCORE_SCHEME,
-                        BOXSCORE_URL,
-                        BOXSCORES_URL)
-from .player import (AbstractPlayer,
-                     _float_property_decorator,
-                     _int_property_decorator)
+from .constants import (
+    BOXSCORE_ELEMENT_INDEX,
+    BOXSCORE_ELEMENT_SUB_INDEX,
+    BOXSCORE_SCHEME,
+    BOXSCORE_URL,
+    BOXSCORES_URL,
+)
+from .player import AbstractPlayer, _float_property_decorator, _int_property_decorator
 from functools import wraps
 
 
@@ -28,13 +28,14 @@ def nfl_int_property_sub_index(func):
         # Equivalent to the calling property's method name
         field = func.__name__
         try:
-            field_items = value.replace('--', '-').split('-')
+            field_items = value.replace("--", "-").split("-")
         except AttributeError:
             return None
         try:
             return int(field_items[BOXSCORE_ELEMENT_SUB_INDEX[field]])
         except (TypeError, ValueError, IndexError):
             return None
+
     return wrapper
 
 
@@ -75,6 +76,7 @@ class BoxscorePlayer(AbstractPlayer):
         page. If the player appears in multiple tables, all of their
         information will appear in one single string concatenated together.
     """
+
     def __init__(self, player_id, player_name, player_data):
         self._index = 0
         self._yards_lost_from_sacks = None
@@ -93,62 +95,59 @@ class BoxscorePlayer(AbstractPlayer):
         properties and values for the specified game.
         """
         fields_to_include = {
-            'completed_passes': self.completed_passes,
-            'attempted_passes': self.attempted_passes,
-            'passing_yards': self.passing_yards,
-            'passing_touchdowns': self.passing_touchdowns,
-            'interceptions_thrown': self.interceptions_thrown,
-            'times_sacked': self.times_sacked,
-            'yards_lost_from_sacks': self.yards_lost_from_sacks,
-            'longest_pass': self.longest_pass,
-            'quarterback_rating': self.quarterback_rating,
-            'rush_attempts': self.rush_attempts,
-            'rush_yards': self.rush_yards,
-            'rush_touchdowns': self.rush_touchdowns,
-            'longest_rush': self.longest_rush,
-            'times_pass_target': self.times_pass_target,
-            'receptions': self.receptions,
-            'receiving_yards': self.receiving_yards,
-            'receiving_touchdowns': self.receiving_touchdowns,
-            'longest_reception': self.longest_reception,
-            'fumbles': self.fumbles,
-            'fumbles_lost': self.fumbles_lost,
-            'interceptions': self.interceptions,
-            'yards_returned_from_interception':
-            self.yards_returned_from_interception,
-            'interceptions_returned_for_touchdown':
-            self.interceptions_returned_for_touchdown,
-            'longest_interception_return': self.longest_interception_return,
-            'passes_defended': self.passes_defended,
-            'sacks': self.sacks,
-            'combined_tackles': self.combined_tackles,
-            'solo_tackles': self.solo_tackles,
-            'assists_on_tackles': self.assists_on_tackles,
-            'tackles_for_loss': self.tackles_for_loss,
-            'quarterback_hits': self.quarterback_hits,
-            'fumbles_recovered': self.fumbles_recovered,
-            'yards_recovered_from_fumble': self.yards_recovered_from_fumble,
-            'fumbles_recovered_for_touchdown':
-            self.fumbles_recovered_for_touchdown,
-            'fumbles_forced': self.fumbles_forced,
-            'kickoff_returns': self.kickoff_returns,
-            'kickoff_return_yards': self.kickoff_return_yards,
-            'average_kickoff_return_yards': self.average_kickoff_return_yards,
-            'kickoff_return_touchdown': self.kickoff_return_touchdown,
-            'longest_kickoff_return': self.longest_kickoff_return,
-            'punt_returns': self.punt_returns,
-            'punt_return_yards': self.punt_return_yards,
-            'yards_per_punt_return': self.yards_per_punt_return,
-            'punt_return_touchdown': self.punt_return_touchdown,
-            'longest_punt_return': self.longest_punt_return,
-            'extra_points_made': self.extra_points_made,
-            'extra_points_attempted': self.extra_points_attempted,
-            'field_goals_made': self.field_goals_made,
-            'field_goals_attempted': self.field_goals_attempted,
-            'punts': self.punts,
-            'total_punt_yards': self.total_punt_yards,
-            'yards_per_punt': self.yards_per_punt,
-            'longest_punt': self.longest_punt
+            "completed_passes": self.completed_passes,
+            "attempted_passes": self.attempted_passes,
+            "passing_yards": self.passing_yards,
+            "passing_touchdowns": self.passing_touchdowns,
+            "interceptions_thrown": self.interceptions_thrown,
+            "times_sacked": self.times_sacked,
+            "yards_lost_from_sacks": self.yards_lost_from_sacks,
+            "longest_pass": self.longest_pass,
+            "quarterback_rating": self.quarterback_rating,
+            "rush_attempts": self.rush_attempts,
+            "rush_yards": self.rush_yards,
+            "rush_touchdowns": self.rush_touchdowns,
+            "longest_rush": self.longest_rush,
+            "times_pass_target": self.times_pass_target,
+            "receptions": self.receptions,
+            "receiving_yards": self.receiving_yards,
+            "receiving_touchdowns": self.receiving_touchdowns,
+            "longest_reception": self.longest_reception,
+            "fumbles": self.fumbles,
+            "fumbles_lost": self.fumbles_lost,
+            "interceptions": self.interceptions,
+            "yards_returned_from_interception": self.yards_returned_from_interception,
+            "interceptions_returned_for_touchdown": self.interceptions_returned_for_touchdown,
+            "longest_interception_return": self.longest_interception_return,
+            "passes_defended": self.passes_defended,
+            "sacks": self.sacks,
+            "combined_tackles": self.combined_tackles,
+            "solo_tackles": self.solo_tackles,
+            "assists_on_tackles": self.assists_on_tackles,
+            "tackles_for_loss": self.tackles_for_loss,
+            "quarterback_hits": self.quarterback_hits,
+            "fumbles_recovered": self.fumbles_recovered,
+            "yards_recovered_from_fumble": self.yards_recovered_from_fumble,
+            "fumbles_recovered_for_touchdown": self.fumbles_recovered_for_touchdown,
+            "fumbles_forced": self.fumbles_forced,
+            "kickoff_returns": self.kickoff_returns,
+            "kickoff_return_yards": self.kickoff_return_yards,
+            "average_kickoff_return_yards": self.average_kickoff_return_yards,
+            "kickoff_return_touchdown": self.kickoff_return_touchdown,
+            "longest_kickoff_return": self.longest_kickoff_return,
+            "punt_returns": self.punt_returns,
+            "punt_return_yards": self.punt_return_yards,
+            "yards_per_punt_return": self.yards_per_punt_return,
+            "punt_return_touchdown": self.punt_return_touchdown,
+            "longest_punt_return": self.longest_punt_return,
+            "extra_points_made": self.extra_points_made,
+            "extra_points_attempted": self.extra_points_attempted,
+            "field_goals_made": self.field_goals_made,
+            "field_goals_attempted": self.field_goals_attempted,
+            "punts": self.punts,
+            "total_punt_yards": self.total_punt_yards,
+            "yards_per_punt": self.yards_per_punt,
+            "longest_punt": self.longest_punt,
         }
         return pd.DataFrame([fields_to_include], index=[self._player_id])
 
@@ -223,6 +222,7 @@ class Boxscore:
         The relative link to the boxscore HTML page, such as
         '201802040nwe'.
     """
+
     def __init__(self, uri):
         self._uri = uri
         self._date = None
@@ -299,8 +299,10 @@ class Boxscore:
         """
         Return the string representation of the class.
         """
-        return (f'Boxscore for {self._away_name.text()} at '
-                f'{self._home_name.text()} ({self.date})')
+        return (
+            f"Boxscore for {self._away_name.text()} at "
+            f"{self._home_name.text()} ({self.date})"
+        )
 
     def __repr__(self):
         """
@@ -335,7 +337,7 @@ class Boxscore:
             return None
         # For NFL, a 404 page doesn't actually raise a 404 error, so it needs
         # to be manually checked.
-        if '404 error' in str(url_data):
+        if "404 error" in str(url_data):
             return None
         return pq(utils._remove_html_comment_tags(url_data))
 
@@ -364,24 +366,24 @@ class Boxscore:
         over_under = None
 
         for line in boxscore(scheme).items():
-            if 'won toss' in str(line).lower():
-                won_toss = line('td').text()
-            elif 'roof' in str(line).lower():
-                roof = line('td').text().title()
-            elif 'surface' in str(line).lower():
-                surface = line('td').text().title()
-            elif 'weather' in str(line).lower():
-                weather = line('td').text()
-            elif 'vegas line' in str(line).lower():
-                vegas_line = line('td').text()
-            elif 'over/under' in str(line).lower():
-                over_under = line('td').text()
-        setattr(self, '_won_toss', won_toss)
-        setattr(self, '_roof', roof)
-        setattr(self, '_surface', surface)
-        setattr(self, '_weather', weather)
-        setattr(self, '_vegas_line', vegas_line)
-        setattr(self, '_over_under', over_under)
+            if "won toss" in str(line).lower():
+                won_toss = line("td").text()
+            elif "roof" in str(line).lower():
+                roof = line("td").text().title()
+            elif "surface" in str(line).lower():
+                surface = line("td").text().title()
+            elif "weather" in str(line).lower():
+                weather = line("td").text()
+            elif "vegas line" in str(line).lower():
+                vegas_line = line("td").text()
+            elif "over/under" in str(line).lower():
+                over_under = line("td").text()
+        setattr(self, "_won_toss", won_toss)
+        setattr(self, "_roof", roof)
+        setattr(self, "_surface", surface)
+        setattr(self, "_weather", weather)
+        setattr(self, "_vegas_line", vegas_line)
+        setattr(self, "_over_under", over_under)
 
     def _parse_game_date_and_location(self, boxscore):
         """
@@ -401,7 +403,7 @@ class Boxscore:
         """
         scheme = BOXSCORE_SCHEME["game_info"]
         items = [i.text() for i in boxscore(scheme).items()]
-        game_info = items[0].split('\n')
+        game_info = items[0].split("\n")
         attendance = None
         date = None
         duration = None
@@ -409,19 +411,19 @@ class Boxscore:
         time = None
         date = game_info[0]
         for line in game_info:
-            if 'Attendance' in line:
-                attendance = line.replace('Attendance: ', '').replace(',', '')
-            if 'Time of Game' in line:
-                duration = line.replace('Time of Game: ', '')
-            if 'Stadium' in line:
-                stadium = line.replace('Stadium: ', '')
-            if 'Start Time' in line:
-                time = line.replace('Start Time: ', '')
-        setattr(self, '_attendance', attendance)
-        setattr(self, '_date', date)
-        setattr(self, '_duration', duration)
-        setattr(self, '_stadium', stadium)
-        setattr(self, '_time', time)
+            if "Attendance" in line:
+                attendance = line.replace("Attendance: ", "").replace(",", "")
+            if "Time of Game" in line:
+                duration = line.replace("Time of Game: ", "")
+            if "Stadium" in line:
+                stadium = line.replace("Stadium: ", "")
+            if "Start Time" in line:
+                time = line.replace("Start Time: ", "")
+        setattr(self, "_attendance", attendance)
+        setattr(self, "_date", date)
+        setattr(self, "_duration", duration)
+        setattr(self, "_stadium", stadium)
+        setattr(self, "_time", time)
 
     def _parse_name(self, field, boxscore):
         """
@@ -473,17 +475,17 @@ class Boxscore:
             Returns a ``dictionary`` representing the score for each team in
             each quarter of the game.
         """
-        team = ['away', 'home']
-        summary = {'away': [], 'home': []}
-        game_summary = boxscore(BOXSCORE_SCHEME['summary'])
-        for ind, team_info in enumerate(game_summary('tbody tr').items()):
+        team = ["away", "home"]
+        summary = {"away": [], "home": []}
+        game_summary = boxscore(BOXSCORE_SCHEME["summary"])
+        for ind, team_info in enumerate(game_summary("tbody tr").items()):
             # Only pull the first N-1 items as the last element is the final
             # score for each team which is already stored in an attribute, and
             # shouldn't be duplicated.
             for quarter in list(team_info('td[class="center"]').items())[:-1]:
                 # The first element contains the logo and name of the teams,
                 # but not any score information, and should be skipped.
-                if quarter('div'):
+                if quarter("div"):
                     continue
                 try:
                     summary[team[ind]].append(int(quarter.text()))
@@ -511,11 +513,10 @@ class Boxscore:
             represents a boxscore table.
         """
         tables = []
-        valid_tables = ['player_offense', 'player_defense', 'returns',
-                        'kicking']
+        valid_tables = ["player_offense", "player_defense", "returns", "kicking"]
 
-        for table in boxscore('table').items():
-            if table.attr['id'] in valid_tables:
+        for table in boxscore("table").items():
+            if table.attr["id"] in valid_tables:
                 tables.append(table)
         return tables
 
@@ -538,7 +539,7 @@ class Boxscore:
             Returns a ``string`` of the player's ID, such as 'BreeDr01'
             for Drew Brees.
         """
-        return row('th').attr('data-append-csv')
+        return row("th").attr("data-append-csv")
 
     def _find_player_name(self, row):
         """
@@ -559,7 +560,7 @@ class Boxscore:
             Returns a ``string`` of the player's full name, such as 'Drew
             Brees'.
         """
-        return row('a:first').text()
+        return row("a:first").text()
 
     def _find_home_or_away(self, row):
         """
@@ -620,7 +621,7 @@ class Boxscore:
             player's name, HTML data, and a string constant indicating which
             team the player is a member of.
         """
-        for row in table('tbody tr').items():
+        for row in table("tbody tr").items():
             player_id = self._find_player_id(row)
             # Occurs when a header row is identified instead of a player.
             if not player_id:
@@ -628,12 +629,12 @@ class Boxscore:
             name = self._find_player_name(row)
             home_or_away = self._find_home_or_away(row)
             try:
-                player_dict[player_id]['data'] += str(row).strip()
+                player_dict[player_id]["data"] += str(row).strip()
             except KeyError:
                 player_dict[player_id] = {
-                    'name': name,
-                    'data': str(row).strip(),
-                    'team': home_or_away
+                    "name": name,
+                    "data": str(row).strip(),
+                    "team": home_or_away,
                 }
         return player_dict
 
@@ -664,10 +665,8 @@ class Boxscore:
         home_players = []
         away_players = []
         for player_id, details in player_dict.items():
-            player = BoxscorePlayer(player_id,
-                                    details['name'],
-                                    details['data'])
-            if details['team'] == HOME:
+            player = BoxscorePlayer(player_id, details["name"], details["data"])
+            if details["team"] == HOME:
                 home_players.append(player)
             else:
                 away_players.append(player)
@@ -724,9 +723,9 @@ class Boxscore:
             abbreviations, respectively.
         """
         abbreviations = []
-        game_info = boxscore(BOXSCORE_SCHEME['team_stats'])
+        game_info = boxscore(BOXSCORE_SCHEME["team_stats"])
 
-        for column in game_info('th').items():
+        for column in game_info("th").items():
             if column.text():
                 abbreviations.append(column.text())
         if not abbreviations:
@@ -761,40 +760,38 @@ class Boxscore:
         for field in self.__dict__:
             # Remove the '_' from the name
             short_field = str(field)[1:]
-            if short_field == 'winner' or \
-               short_field == 'winning_name' or \
-               short_field == 'winning_abbr' or \
-               short_field == 'losing_name' or \
-               short_field == 'losing_abbr' or \
-               short_field == 'uri' or \
-               short_field == 'date' or \
-               short_field == 'time' or \
-               short_field == 'stadium' or \
-               short_field == 'attendance' or \
-               short_field == 'duration' or \
-               short_field == 'won_toss' or \
-               short_field == 'roof' or \
-               short_field == 'surface' or \
-               short_field == 'weather' or \
-               short_field == 'vegas_line' or \
-               short_field == 'over_under':
+            if (
+                short_field == "winner"
+                or short_field == "winning_name"
+                or short_field == "winning_abbr"
+                or short_field == "losing_name"
+                or short_field == "losing_abbr"
+                or short_field == "uri"
+                or short_field == "date"
+                or short_field == "time"
+                or short_field == "stadium"
+                or short_field == "attendance"
+                or short_field == "duration"
+                or short_field == "won_toss"
+                or short_field == "roof"
+                or short_field == "surface"
+                or short_field == "weather"
+                or short_field == "vegas_line"
+                or short_field == "over_under"
+            ):
                 continue
-            if short_field == 'away_name' or \
-               short_field == 'home_name':
+            if short_field == "away_name" or short_field == "home_name":
                 value = self._parse_name(short_field, boxscore)
                 setattr(self, field, value)
                 continue
-            if short_field == 'summary':
+            if short_field == "summary":
                 value = self._parse_summary(boxscore)
                 setattr(self, field, value)
                 continue
             index = 0
             if short_field in BOXSCORE_ELEMENT_INDEX.keys():
                 index = BOXSCORE_ELEMENT_INDEX[short_field]
-            value = utils._parse_field(BOXSCORE_SCHEME,
-                                       boxscore,
-                                       short_field,
-                                       index)
+            value = utils._parse_field(BOXSCORE_SCHEME, boxscore, short_field, index)
             setattr(self, field, value)
         self._parse_game_date_and_location(boxscore)
         self._parse_game_details(boxscore)
@@ -809,74 +806,74 @@ class Boxscore:
         instantiate the class, such as '201802040nwe'.
         """
         for points in [self._away_points, self._home_points]:
-            if points is None or points == '':
+            if points is None or points == "":
                 return None
         fields_to_include = {
-            'attendance': self.attendance,
-            'away_first_downs': self.away_first_downs,
-            'away_fourth_down_attempts': self.away_fourth_down_attempts,
-            'away_fourth_down_conversions': self.away_fourth_down_conversions,
-            'away_fumbles': self.away_fumbles,
-            'away_fumbles_lost': self.away_fumbles_lost,
-            'away_interceptions': self.away_interceptions,
-            'away_net_pass_yards': self.away_net_pass_yards,
-            'away_pass_attempts': self.away_pass_attempts,
-            'away_pass_completions': self.away_pass_completions,
-            'away_pass_touchdowns': self.away_pass_touchdowns,
-            'away_pass_yards': self.away_pass_yards,
-            'away_penalties': self.away_penalties,
-            'away_points': self.away_points,
-            'away_rush_attempts': self.away_rush_attempts,
-            'away_rush_touchdowns': self.away_rush_touchdowns,
-            'away_rush_yards': self.away_rush_yards,
-            'away_third_down_attempts': self.away_third_down_attempts,
-            'away_third_down_conversions': self.away_third_down_conversions,
-            'away_time_of_possession': self.away_time_of_possession,
-            'away_times_sacked': self.away_times_sacked,
-            'away_total_yards': self.away_total_yards,
-            'away_turnovers': self.away_turnovers,
-            'away_yards_from_penalties': self.away_yards_from_penalties,
-            'away_yards_lost_from_sacks': self.away_yards_lost_from_sacks,
-            'date': self.date,
-            'datetime': self.datetime,
-            'duration': self.duration,
-            'home_first_downs': self.home_first_downs,
-            'home_fourth_down_attempts': self.home_fourth_down_attempts,
-            'home_fourth_down_conversions': self.home_fourth_down_conversions,
-            'home_fumbles': self.home_fumbles,
-            'home_fumbles_lost': self.home_fumbles_lost,
-            'home_interceptions': self.home_interceptions,
-            'home_net_pass_yards': self.home_net_pass_yards,
-            'home_pass_attempts': self.home_pass_attempts,
-            'home_pass_completions': self.home_pass_completions,
-            'home_pass_touchdowns': self.home_pass_touchdowns,
-            'home_pass_yards': self.home_pass_yards,
-            'home_penalties': self.home_penalties,
-            'home_points': self.home_points,
-            'home_rush_attempts': self.home_rush_attempts,
-            'home_rush_touchdowns': self.home_rush_touchdowns,
-            'home_rush_yards': self.home_rush_yards,
-            'home_third_down_attempts': self.home_third_down_attempts,
-            'home_third_down_conversions': self.home_third_down_conversions,
-            'home_time_of_possession': self.home_time_of_possession,
-            'home_times_sacked': self.home_times_sacked,
-            'home_total_yards': self.home_total_yards,
-            'home_turnovers': self.home_turnovers,
-            'home_yards_from_penalties': self.home_yards_from_penalties,
-            'home_yards_lost_from_sacks': self.home_yards_lost_from_sacks,
-            'losing_abbr': self.losing_abbr,
-            'losing_name': self.losing_name,
-            'over_under': self.over_under,
-            'roof': self.roof,
-            'stadium': self.stadium,
-            'surface': self.surface,
-            'time': self.time,
-            'vegas_line': self.vegas_line,
-            'weather': self.weather,
-            'winner': self.winner,
-            'winning_abbr': self.winning_abbr,
-            'winning_name': self.winning_name,
-            'won_toss': self.won_toss
+            "attendance": self.attendance,
+            "away_first_downs": self.away_first_downs,
+            "away_fourth_down_attempts": self.away_fourth_down_attempts,
+            "away_fourth_down_conversions": self.away_fourth_down_conversions,
+            "away_fumbles": self.away_fumbles,
+            "away_fumbles_lost": self.away_fumbles_lost,
+            "away_interceptions": self.away_interceptions,
+            "away_net_pass_yards": self.away_net_pass_yards,
+            "away_pass_attempts": self.away_pass_attempts,
+            "away_pass_completions": self.away_pass_completions,
+            "away_pass_touchdowns": self.away_pass_touchdowns,
+            "away_pass_yards": self.away_pass_yards,
+            "away_penalties": self.away_penalties,
+            "away_points": self.away_points,
+            "away_rush_attempts": self.away_rush_attempts,
+            "away_rush_touchdowns": self.away_rush_touchdowns,
+            "away_rush_yards": self.away_rush_yards,
+            "away_third_down_attempts": self.away_third_down_attempts,
+            "away_third_down_conversions": self.away_third_down_conversions,
+            "away_time_of_possession": self.away_time_of_possession,
+            "away_times_sacked": self.away_times_sacked,
+            "away_total_yards": self.away_total_yards,
+            "away_turnovers": self.away_turnovers,
+            "away_yards_from_penalties": self.away_yards_from_penalties,
+            "away_yards_lost_from_sacks": self.away_yards_lost_from_sacks,
+            "date": self.date,
+            "datetime": self.datetime,
+            "duration": self.duration,
+            "home_first_downs": self.home_first_downs,
+            "home_fourth_down_attempts": self.home_fourth_down_attempts,
+            "home_fourth_down_conversions": self.home_fourth_down_conversions,
+            "home_fumbles": self.home_fumbles,
+            "home_fumbles_lost": self.home_fumbles_lost,
+            "home_interceptions": self.home_interceptions,
+            "home_net_pass_yards": self.home_net_pass_yards,
+            "home_pass_attempts": self.home_pass_attempts,
+            "home_pass_completions": self.home_pass_completions,
+            "home_pass_touchdowns": self.home_pass_touchdowns,
+            "home_pass_yards": self.home_pass_yards,
+            "home_penalties": self.home_penalties,
+            "home_points": self.home_points,
+            "home_rush_attempts": self.home_rush_attempts,
+            "home_rush_touchdowns": self.home_rush_touchdowns,
+            "home_rush_yards": self.home_rush_yards,
+            "home_third_down_attempts": self.home_third_down_attempts,
+            "home_third_down_conversions": self.home_third_down_conversions,
+            "home_time_of_possession": self.home_time_of_possession,
+            "home_times_sacked": self.home_times_sacked,
+            "home_total_yards": self.home_total_yards,
+            "home_turnovers": self.home_turnovers,
+            "home_yards_from_penalties": self.home_yards_from_penalties,
+            "home_yards_lost_from_sacks": self.home_yards_lost_from_sacks,
+            "losing_abbr": self.losing_abbr,
+            "losing_name": self.losing_name,
+            "over_under": self.over_under,
+            "roof": self.roof,
+            "stadium": self.stadium,
+            "surface": self.surface,
+            "time": self.time,
+            "vegas_line": self.vegas_line,
+            "weather": self.weather,
+            "winner": self.winner,
+            "winning_abbr": self.winning_abbr,
+            "winning_name": self.winning_name,
+            "won_toss": self.won_toss,
         }
         return pd.DataFrame([fields_to_include], index=[self._uri])
 
@@ -901,8 +898,8 @@ class Boxscore:
         """
         Returns a ``string`` of the away team's abbreviation, such as 'NWE'.
         """
-        abbr = re.sub(r'.*/teams/', '', str(self._away_name))
-        abbr = re.sub(r'/.*', '', abbr)
+        abbr = re.sub(r".*/teams/", "", str(self._away_name))
+        abbr = re.sub(r"/.*", "", abbr)
         return abbr
 
     @property
@@ -910,8 +907,8 @@ class Boxscore:
         """
         Returns a ``string`` of the home team's abbreviation, such as 'KAN'.
         """
-        abbr = re.sub(r'.*/teams/', '', str(self._home_name))
-        abbr = re.sub(r'/.*', '', abbr)
+        abbr = re.sub(r".*/teams/", "", str(self._home_name))
+        abbr = re.sub(r"/.*", "", abbr)
         return abbr
 
     @property
@@ -935,10 +932,10 @@ class Boxscore:
         """
         dt = None
         if self._date and self._time:
-            date = '%s %s' % (self._date, self._time)
-            dt = datetime.strptime(date, '%A %b %d, %Y %I:%M%p')
+            date = "%s %s" % (self._date, self._time)
+            dt = datetime.strptime(date, "%A %b %d, %Y %I:%M%p")
         elif self._date:
-            dt = datetime.strptime(self._date, '%A %b %d, %Y')
+            dt = datetime.strptime(self._date, "%A %b %d, %Y")
         return dt
 
     @property
@@ -1460,6 +1457,7 @@ class Boxscores:
         empty, or if 'end_week' is prior to 'week', only the games from the day
         specified in the 'date' parameter will be saved.
     """
+
     def __init__(self, week, year, end_week=None):
         self._boxscores = {}
 
@@ -1469,7 +1467,7 @@ class Boxscores:
         """
         Return the string representation of the class.
         """
-        weeks = [week.split('-')[0] for week in sorted(self._boxscores.keys())]
+        weeks = [week.split("-")[0] for week in sorted(self._boxscores.keys())]
         if len(weeks) > 1:
             return f"NFL games for weeks {', '.join(weeks)}"
         return f"NFL games for week {weeks[0]}"
@@ -1579,8 +1577,8 @@ class Boxscores:
             Returns a ``string`` containing the link to the game's boxscore
             page.
         """
-        uri = re.sub(r'.*/boxscores/', '', str(url))
-        uri = re.sub(r'\.htm.*', '', uri).strip()
+        uri = re.sub(r".*/boxscores/", "", str(url))
+        uri = re.sub(r"\.htm.*", "", uri).strip()
         return uri
 
     def _parse_abbreviation(self, abbr):
@@ -1599,8 +1597,8 @@ class Boxscores:
         string
             Returns a ``string`` of the team's abbreviation.
         """
-        abbr = re.sub(r'.*/teams/', '', str(abbr))
-        abbr = re.sub(r'/.*', '', abbr)
+        abbr = re.sub(r".*/teams/", "", str(abbr))
+        abbr = re.sub(r"/.*", "", abbr)
         return abbr
 
     def _get_name(self, name):
@@ -1642,8 +1640,8 @@ class Boxscores:
         int
             Returns an int representing the team's final score in runs.
         """
-        score = score_link.replace('<td class="right">', '')
-        score = score.replace('</td>', '')
+        score = score_link.replace('<td class="right">', "")
+        score = score.replace("</td>", "")
         return int(score)
 
     def _get_team_details(self, game):
@@ -1666,7 +1664,7 @@ class Boxscores:
             teams in the following order: Away Name, Away Abbreviation, Away
             Score, Home Name, Home Abbreviation, Home Score.
         """
-        links = [i for i in game('td a').items()]
+        links = [i for i in game("td a").items()]
         # The away team is the first link in the boxscore
         away = links[0]
         # The home team is the last (3rd) link in the boxscore
@@ -1681,8 +1679,7 @@ class Boxscores:
             home_score = self._get_score(scores[1])
         away_name, away_abbr = self._get_name(away)
         home_name, home_abbr = self._get_name(home)
-        return (away_name, away_abbr, away_score, home_name, home_abbr,
-                home_score)
+        return (away_name, away_abbr, away_score, home_name, home_abbr, home_score)
 
     def _get_team_results(self, team_result_html):
         """
@@ -1703,7 +1700,7 @@ class Boxscores:
         tuple
             Returns a tuple of the team's name followed by the abbreviation.
         """
-        link = [i for i in team_result_html('td a').items()]
+        link = [i for i in team_result_html("td a").items()]
         # If there are no links, the boxscore is likely misformed and can't be
         # parsed. In this case, the boxscore should be skipped.
         if len(link) < 1:
@@ -1735,8 +1732,7 @@ class Boxscores:
 
         for game in games:
             details = self._get_team_details(game)
-            away_name, away_abbr, away_score, home_name, home_abbr, \
-                home_score = details
+            away_name, away_abbr, away_score, home_name, home_abbr, home_score = details
             boxscore_url = game('td[class="right gamelink"] a')
             boxscore_uri = self._get_boxscore_uri(boxscore_url)
             losers = [loser for loser in game('tr[class="loser"]').items()]
@@ -1744,8 +1740,9 @@ class Boxscores:
             loser = self._get_team_results(game('tr[class="loser"]'))
             # Occurs when the boxscore format is invalid and the game should be
             # skipped to avoid conflicts populating the game information.
-            if (len(losers) != 2 and loser and not winner) or \
-               (len(losers) != 2 and winner and not loser):
+            if (len(losers) != 2 and loser and not winner) or (
+                len(losers) != 2 and winner and not loser
+            ):
                 continue
             # Occurs when information couldn't be parsed from the boxscore or
             # the game hasn't occurred yet. In this case, the winner should be
@@ -1764,17 +1761,17 @@ class Boxscores:
             else:
                 losing_name, losing_abbreviation = loser
             game_info = {
-                'boxscore': boxscore_uri,
-                'away_name': away_name,
-                'away_abbr': away_abbr,
-                'away_score': away_score,
-                'home_name': home_name,
-                'home_abbr': home_abbr,
-                'home_score': home_score,
-                'winning_name': winning_name,
-                'winning_abbr': winning_abbreviation,
-                'losing_name': losing_name,
-                'losing_abbr': losing_abbreviation
+                "boxscore": boxscore_uri,
+                "away_name": away_name,
+                "away_abbr": away_abbr,
+                "away_score": away_score,
+                "home_name": home_name,
+                "home_abbr": home_abbr,
+                "home_score": home_score,
+                "winning_name": winning_name,
+                "winning_abbr": winning_abbreviation,
+                "losing_name": losing_name,
+                "losing_abbr": losing_abbreviation,
             }
             all_boxscores.append(game_info)
         return all_boxscores
@@ -1810,6 +1807,6 @@ class Boxscores:
             page = self._get_requested_page(url)
             games = page('table[class="teams"]').items()
             boxscores = self._extract_game_info(games)
-            timestamp = '%s-%s' % (week, year)
+            timestamp = "%s-%s" % (week, year)
             self._boxscores[timestamp] = boxscores
             week += 1
